=======
History
=======

1.1.0 (2023-12-14)
------------------

* Complete rewrite of everything allowing more robust dimension reduction and Markov model construction of MD trajectories.

0.1.0 (2023-01-13)
------------------

* First release on PyPI.
